@@ -22,7 +22,7 @@
 ###         R functions
 ### 
 
-plotdist <- function(data, distr, para, breaks="default", discrete, ...)
+plotdist <- function(data, distr, para, histo = TRUE, breaks="default", demp = FALSE, discrete,  ...)
 {
     def.par <- par(no.readonly = TRUE)
     if (missing(data) || !is.vector(data, mode="numeric"))
@@ -30,6 +30,8 @@ plotdist <- function(data, distr, para, breaks="default", discrete, ...)
     if ((missing(distr) & !missing(para)) || 
     (missing(distr) & !missing(para)))
         stop("distr and para must defined")
+    if (!histo & !demp)
+      stop("one the arguments histo and demp must be put to TRUE")
     xlim <- c(min(data), max(data)) # for plot of discrete distributions
     s <- sort(data)
     n <- length(data)
@@ -43,10 +45,35 @@ plotdist <- function(data, distr, para, breaks="default", discrete, ...)
       {
             # plot for continuous data alone
             obsp <- ppoints(s)
-            if (breaks=="default") 
-                h <- hist(data, freq=FALSE, xlab="Data", main=paste("Histogram"), ...)
-            else 
-                h <- hist(data, freq=FALSE, xlab="Data", main=paste("Histogram"), breaks=breaks, ...)
+            # PLOT 1 ---
+            if (histo)
+            {
+              if(demp)
+              {
+                if (breaks=="default") 
+                  h <- hist(data, freq=FALSE, xlab="Data", main="Empirical density", ...)
+                else 
+                  h <- hist(data, freq=FALSE, xlab="Data", main="Empirical density", 
+                            breaks=breaks, ...)
+                lines(density(data)$x, density(data)$y, lty=2, col="black")
+              }
+              else
+              {
+                if (breaks=="default") 
+                  h <- hist(data, freq=FALSE, xlab="Data", main="Histogram", ...)
+                else 
+                  h <- hist(data, freq=FALSE, xlab="Data", main="Histogram", 
+                            breaks=breaks, ...)
+              }
+            }
+            else
+            {
+              h <- hist(data, freq=FALSE, xlab="Data", main="Histogram", plot = FALSE, ...)
+              plot(density(data)$x, density(data)$y, lty=1, col="black", type = "l",
+                   xlab="Data", main=paste("Empirical density"), ylab = "Density",...)
+            }
+            
+            # PLOT 2 ---
             plot(s, obsp, main=paste("Cumulative distribution"), xlab="Data", 
 				      xlim=c(h$breaks[1], h$breaks[length(h$breaks)]), ylab="CDF", ...)
       }
@@ -110,7 +137,7 @@ plotdist <- function(data, distr, para, breaks="default", discrete, ...)
             par(mfrow=c(2, 2))
             obsp <- ppoints(s)
             theop <- do.call(pdistname, c(list(q=s), as.list(para)))
-            # plot of the histogram with theoretical density
+            # plot of empirical and theoretical density
             # computes densities in order to define limits for y-axis
             if (breaks=="default")
                 h <- hist(data, plot=FALSE)
@@ -119,17 +146,35 @@ plotdist <- function(data, distr, para, breaks="default", discrete, ...)
             xhist <- seq(min(h$breaks), max(h$breaks), length=1000)
             yhist <- do.call(ddistname, c(list(x=xhist), as.list(para)))
             ymax <- ifelse(is.finite(max(yhist)), max(max(h$density), max(yhist)), max(h$density)) 
-            # plot of histograms and theoretical density
-            hist(data, freq=FALSE, xlab="Data", ylim=c(0, ymax), breaks=h$breaks, 
-                main=paste("Empirical and theoretical distr."), ...)
+            # PLOT 1 - plot of empirical and  theoretical density
+            # empirical density
+            if (histo)
+            {
+              hist(data, freq=FALSE, xlab="Data", ylim=c(0, ymax), breaks=h$breaks, 
+                   main=paste("Empirical and theoretical dens."), ...)
+              if(demp)
+              {
+                lines(density(data)$x, density(data)$y, lty=2, col="black")
+              }
+            }
+            else
+              plot(density(data)$x, density(data)$y, lty=2, col="black", type = "l",
+                   xlab="Data", main=paste("Empirical and theoretical dens."),
+                   ylab = "Density", xlim = c(min(h$breaks), max(h$breaks)), ...)
+            if (demp)
+              legend("topright",bty="n",lty=c(2,1),col=c("black","red"),
+                     legend=c("empirical","theoretical"), bg="white",cex=0.7)
+            
+            # Add of theoretical density
             lines(xhist, yhist,lty=1,col="red")
            
-            # plot of the qqplot
+            # PLOT 2 - plot of the qqplot
             theoq <- do.call(qdistname, c(list(p=obsp), as.list(para)))
             plot(theoq, s, main=" Q-Q plot", xlab="Theoretical quantiles", 
 				      ylab="Empirical quantiles", ...)
             abline(0, 1)
-            # plot of the cumulative probability distributions
+              
+            # PLOT 3 - plot of the cumulative probability distributions
             xmin <- h$breaks[1]
             xmax <- h$breaks[length(h$breaks)]
             plot(s, obsp, main=paste("Empirical and theoretical CDFs"), xlab="Data", 
@@ -138,7 +183,7 @@ plotdist <- function(data, distr, para, breaks="default", discrete, ...)
             theopfin <- do.call(pdistname, c(list(q=sfin), as.list(para)))
             lines(sfin, theopfin, lty=1,col="red")
             
-            # plot of the ppplot
+            # PLOT 4 - plot of the ppplot
             plot(theop, obsp, main="P-P plot", xlab="Theoretical probabilities", 
 				      ylab="Empirical probabilities", ...)
             abline(0, 1)
