@@ -2,12 +2,15 @@ library(fitdistrplus)
 
 # (1) Plot of an empirical distribution with changing 
 # of default line types for CDF and colors
+# and optionally adding a density line
 #
 set.seed(1234)
 x1 <- rnorm(n=30)
 plotdist(x1)
 plotdist(x1, col="blue", type="b", pch=16)
 plotdist(x1, type="s")
+plotdist(x1, demp = TRUE)
+plotdist(x1,demp = TRUE, adjust = 1.5)
 
 # (2) Plot of a discrete distribution against data
 #
@@ -22,6 +25,8 @@ plotdist(x2, "pois", para=list(lambda = mean(x2)), lwd="2")
 xn <- rnorm(n=100, mean=10, sd=5)
 plotdist(xn, "norm", para=list(mean=mean(xn), sd=sd(xn)))
 plotdist(xn, "norm", para=list(mean=mean(xn), sd=sd(xn)), pch=16)
+plotdist(xn, "norm", para=list(mean=mean(xn), sd=sd(xn)), pch=16,
+         demp = TRUE)
 
 # (4) Plot of serving size data
 #
